==> haskell-th-lift-instances-0.1.11-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-APth76Ghxq08bBicuHMIia
key: th-lift-instances-0.1.11-APth76Ghxq08bBicuHMIia
license: BSD3
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
author: Benno Fünfstück
exposed: True
indefinite: False
exposed-modules:
    Instances.TH.Lift
abi: 208fb172eb68607b2d79f2ada1a06cce
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-APth76Ghxq08bBicuHMIia
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
    th-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU containers-0.5.10.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU=84b4af8038e4d3e40fa101158d0ce5f8
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.11-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-GbnQOH2K7Mx6pX0wfMQd1l
key: th-lift-instances-0.1.11-GbnQOH2K7Mx6pX0wfMQd1l
license: BSD3
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
author: Benno Fünfstück
exposed: True
indefinite: False
exposed-modules:
    Instances.TH.Lift
abi: 2ad370bbfd1bfdc3865a57e85b133962
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-GbnQOH2K7Mx6pX0wfMQd1l
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
    th-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU containers-0.5.10.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU=84b4af8038e4d3e40fa101158d0ce5f8
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
